@@ -5,7 +5,9 @@
 
 class About;
 class Help;
-class fResistors;
+class wResistors;
+class Ohmsa;
+class Power;
 
 namespace Ui {
     class MainWindow;
@@ -32,17 +34,23 @@ public:
 
 private slots:
 
-    void on_pushButtonResistor_clicked();
-
     void on_actionAbout_triggered();
 
     void on_actionHelp_triggered();
 
+    void on_pushButtonResistor_clicked();
+
+    void on_pushButtonOhmsa_clicked();
+
+    void on_pushButtonPower_clicked();
+
 private:
     Ui::MainWindow *ui;
     About *about;
     Help *help;
-    fResistors *fresistors;
+    wResistors *wresistors;
+    Ohmsa *ohmsa;
+    Power *power;
 
 };
 
